@@ -1,13 +1,19 @@
-from app.core.config import settings
 import random
 import string
 from asyncio import AbstractEventLoop as EventLoop
 from typing import Dict
-from app import crud
+
 from fastapi.testclient import TestClient
+
+from app import crud
+from app.core.config import settings
 from app.schemas import UserCreateBySuperuser
 
 
+def random_integer_below_100() -> int:
+    return random.randint(0, 99)
+
+
 def random_lower_string(length=20) -> str:
     return "".join(random.choices(string.ascii_lowercase, k=length))
 
@@ -34,4 +40,4 @@ def user_authentication_headers(
     response = r.json()
     auth_token = response["access_token"]
     headers = {"Authorization": f"Bearer {auth_token}"}
-    return headers
\ No newline at end of file
+    return headers
